@@ -1,4 +1,4 @@
-/* $Id: thunar-vfs-volume-hal.c 24532 2007-01-18 14:51:28Z benny $ */
+/* $Id: thunar-vfs-volume-hal.c 26396 2007-11-28 19:48:23Z benny $ */
 /*-
  * Copyright (c) 2005-2007 Benedikt Meurer <benny@xfce.org>
  *
@@ -53,6 +53,7 @@ static ThunarVfsVolumeKind   thunar_vfs_volume_hal_get_kind                 (Thu
 static const gchar          *thunar_vfs_volume_hal_get_name                 (ThunarVfsVolume          *volume);
 static ThunarVfsVolumeStatus thunar_vfs_volume_hal_get_status               (ThunarVfsVolume          *volume);
 static ThunarVfsPath        *thunar_vfs_volume_hal_get_mount_point          (ThunarVfsVolume          *volume);
+static gboolean              thunar_vfs_volume_hal_is_ejectable             (ThunarVfsVolume          *volume);
 static const gchar          *thunar_vfs_volume_hal_lookup_icon_name         (ThunarVfsVolume          *volume,
                                                                              GtkIconTheme             *icon_theme);
 static gboolean              thunar_vfs_volume_hal_eject                    (ThunarVfsVolume          *volume,
@@ -90,6 +91,7 @@ struct _ThunarVfsVolumeHal
   /* list of possible icons */
   GList                *icon_list;
 
+  gboolean              requires_eject;
   ThunarVfsPath        *mount_point;
   ThunarVfsVolumeKind   kind;
   ThunarVfsVolumeStatus status;
@@ -139,6 +141,7 @@ thunar_vfs_volume_hal_class_init (ThunarVfsVolumeHalClass *klass)
   thunarvfs_volume_class->get_name = thunar_vfs_volume_hal_get_name;
   thunarvfs_volume_class->get_status = thunar_vfs_volume_hal_get_status;
   thunarvfs_volume_class->get_mount_point = thunar_vfs_volume_hal_get_mount_point;
+  thunarvfs_volume_class->is_ejectable = thunar_vfs_volume_hal_is_ejectable;
   thunarvfs_volume_class->lookup_icon_name = thunar_vfs_volume_hal_lookup_icon_name;
   thunarvfs_volume_class->eject = thunar_vfs_volume_hal_eject;
   thunarvfs_volume_class->mount = thunar_vfs_volume_hal_mount;
@@ -201,6 +204,19 @@ thunar_vfs_volume_hal_get_mount_point (ThunarVfsVolume *volume)
 
 
 
+static gboolean
+thunar_vfs_volume_hal_is_ejectable (ThunarVfsVolume *volume)
+{
+  /* check if HAL drive requires eject */
+  if (THUNAR_VFS_VOLUME_HAL (volume)->requires_eject)
+    return TRUE;
+
+  /* otherwise we can only eject removable media, that are present (surprise, surprise) */
+  return (thunar_vfs_volume_is_present (volume) && thunar_vfs_volume_is_removable (volume));
+}
+
+
+
 static const gchar*
 thunar_vfs_volume_hal_lookup_icon_name (ThunarVfsVolume *volume,
                                         GtkIconTheme    *icon_theme)
@@ -520,6 +536,13 @@ thunar_vfs_volume_hal_update (ThunarVfsVolumeHal *volume_hal,
    * a drive, which means non-pollable then, so it's present
    */
   volume_hal->status |= THUNAR_VFS_VOLUME_STATUS_PRESENT;
+  
+  /* figure out if the volume is mountable */
+  if(hv != NULL && libhal_volume_get_fsusage (hv) == LIBHAL_VOLUME_USAGE_MOUNTABLE_FILESYSTEM)
+    volume_hal->status |= THUNAR_VFS_VOLUME_STATUS_MOUNTABLE;
+
+  /* check if the drive requires eject */
+  volume_hal->requires_eject = libhal_drive_requires_eject (hd);
 
   /* check if the volume is currently mounted */
   if (hv != NULL && libhal_volume_is_mounted (hv))
@@ -980,11 +1003,21 @@ thunar_vfs_volume_manager_hal_device_added (LibHalContext *context,
   _thunar_vfs_return_if_fail (THUNAR_VFS_IS_VOLUME_MANAGER_HAL (manager_hal));
   _thunar_vfs_return_if_fail (manager_hal->context == context);
 
+  /* check if we have a volume here */
+  hv = libhal_volume_from_udi (context, udi);
+
+  /* HAL might want us to ignore this volume for some reason */
+  if (G_UNLIKELY (hv != NULL
+        && (libhal_volume_should_ignore (hv)
+          || libhal_volume_get_fsusage (hv) != LIBHAL_VOLUME_USAGE_MOUNTABLE_FILESYSTEM)))
+    {
+      libhal_volume_free (hv);
+      return;
+    }
+
   /* emit the "device-added" signal (to support thunar-volman) */
   g_signal_emit_by_name (G_OBJECT (manager_hal), "device-added", udi);
 
-  /* check if we have a volume here */
-  hv = libhal_volume_from_udi (context, udi);
   if (G_LIKELY (hv != NULL))
     {
       /* determine the UDI of the drive to which this volume belongs */
@@ -1076,7 +1109,7 @@ thunar_vfs_volume_manager_hal_device_removed (LibHalContext *context,
   _thunar_vfs_return_if_fail (manager_hal->context == context);
 
   /* emit the "device-removed" signal (to support thunar-volman) */
-  g_signal_emit_by_name (G_OBJECT (manager_hal), "device-added", udi);
+  g_signal_emit_by_name (G_OBJECT (manager_hal), "device-removed", udi);
 
   /* check if we already have a volume object for the UDI */
   volume_hal = thunar_vfs_volume_manager_hal_get_volume_by_udi (manager_hal, udi);
